@@ -1,7 +1,7 @@
 import os
-dwKLH=False
-dwKLY=True
-dwKLR=Exception
+VxiJu=False
+VxiJc=True
+VxiJM=Exception
 import logging
 import traceback
 import localstack
@@ -82,18 +82,18 @@ def setup_ssl_cert():
    return
  download_github_artifact(SSL_CERT_URL,target_file)
 def download_github_artifact(url,target_file):
- def do_download(url,print_error=dwKLH):
+ def do_download(url,print_error=VxiJu):
   try:
    download(url,target_file)
-   return dwKLY
-  except dwKLR as e:
+   return VxiJc
+  except VxiJM as e:
    if print_error:
     LOG.info('Unable to download local test SSL certificate from %s to %s: %s %s'%(url,target_file,e,traceback.format_exc()))
  result=do_download(url)
  if not result:
   url=url.replace('https://github.com','https://cdn.jsdelivr.net/gh')
   url=url.replace('/raw/master/','@master/')
-  do_download(url,dwKLY)
+  do_download(url,VxiJc)
 def install_h2():
  target_dir=os.path.join(INFRA_DIR,'h2')
  if not os.path.exists(target_dir):
